/*
 * Copyright (c) 2011-2015 BlackBerry Limited.
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.apache.org/licenses/LICENSE-2.0
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import bb.cascades 1.2

Page {
    
    id: browserPage
    actionBarAutoHideBehavior: ActionBarAutoHideBehavior.HideOnScroll
    
    titleBar: TitleBar {
        title: "Dis10 | Just A Discord App"
    }
    
    Container {
        
        layout: StackLayout {
        }
        
        Container {
            preferredHeight: 10
            maxHeight: 10
            horizontalAlignment: HorizontalAlignment.Fill
            
            ProgressIndicator {
                maxHeight: 10
                preferredHeight: 10
                id: updateProgressIndicator
                accessibility.name: "Progress Indicator"
                accessibility.description: "Progress Indicator for Updates"
                horizontalAlignment: HorizontalAlignment.Fill
            }
        }
        
        ScrollView {
            
            id: scrollView
            scrollRole: ScrollRole.Main
            verticalAlignment: VerticalAlignment.Fill
            horizontalAlignment: HorizontalAlignment.Fill
            
            implicitLayoutAnimationsEnabled: false
            scrollViewProperties.minContentScale: 1.0
            
            scrollViewProperties {
                scrollMode: ScrollMode.None
                pinchToZoomEnabled: true
            }
            
            layoutProperties: StackLayoutProperties {
                spaceQuota: 1.0
            }
            
            WebView {
                
                id: webview
                url: "https://discordapp.com/channels/@me"
                horizontalAlignment: HorizontalAlignment.Fill
                verticalAlignment: VerticalAlignment.Fill
                settings.background: Color.Black
                
                // settings.zoomToFitEnabled: true
                settings.activeTextEnabled: true
                settings.viewport: {
                    "width": "device-width",
                    "height": "device-height",
                    "initial-scale": 1.0
                }
                
                onMinContentScaleChanged: {
                    scrollView.scrollViewProperties.minContentScale = minContentScale;
                }
                
                onMaxContentScaleChanged: {
                    scrollView.scrollViewProperties.maxContentScale = maxContentScale;
                }
                
                onLoadProgressChanged: {
                    updateProgressIndicator.value = loadProgress / 100.0
                }
                settings.credentialAutoFillEnabled: true
                settings.formAutoFillEnabled: true
                settings.zoomToFitEnabled: true
                settings.defaultFontSizeFollowsSystemFontSize: true
                settings.userStyleSheetLocation: "asset:///css/style.css"
            }
            
            attachedObjects: LayoutUpdateHandler {                    
                onLayoutFrameChanged: {
                    webview.preferredWidth = layoutFrame.width;
                    webview.preferredHeight = layoutFrame.height;
                }
            }
        }    
    }
    
    actions: [
        ActionItem {
            title: qsTr("Home") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///icons/a_review.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            shortcuts: [
                Shortcut {
                    key: "H"
                },
                Shortcut { key: "h" }]            
            onTriggered: {
                webview.url = "https://discordapp.com/channels/@me";
            }
        },
        ActionItem {
            title: qsTr("Back") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///icons/a_previous.png"
            ActionBar.placement: ActionBarPlacement.OnBar
            shortcuts: [
                Shortcut { key: "B" },
                Shortcut { key: "b" }]            
            onTriggered: {
                webview.goBack();
            }
        },
        ActionItem {
            title: qsTr("Clear Cache") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///icons/a_remove.png"
            ActionBar.placement: ActionBarPlacement.InOverflow
            shortcuts: [
                Shortcut {
                    key: "C"
                },
                Shortcut { key: "c" }]            
            onTriggered: {
                webview.storage.clear();
            }
        },
        ActionItem {            
            title: qsTr("Refresh") + Retranslate.onLocaleOrLanguageChanged
            imageSource: "asset:///icons/a_scan.png"
            ActionBar.placement: ActionBarPlacement.Signature
            shortcuts: [ Shortcut { key: "R" }, Shortcut { key: "r" }]            
            onTriggered: {
                webview.reload();
            }
        }
    ]

}
